@@ -104,9 +104,9 @@ FreeStringList(char **paths)
 	return;
 
     for (p = paths; *p; p++)
-	xfree(*p);
+	free(*p);
 
-    xfree(paths);
+    free(paths);
 }
 
 static char **defaultPathList = NULL;
@@ -114,7 +114,7 @@ static char **defaultPathList = NULL;
 static Bool
 PathIsAbsolute(const char *path)
 {
-    return (*path == '/');
+    return *path == '/';
 }	
 
 /*
@@ -135,7 +135,7 @@ InitPathList(const char *path)
     if (!path)
 	return defaultPathList;
 
-    fullpath = xstrdup(path);
+    fullpath = strdup(path);
     if (!fullpath)
 	return NULL;
     elem = strtok(fullpath, ",");
@@ -147,19 +147,19 @@ InitPathList(const char *path)
 	    if (addslash)
 		len++;
 	    save = list;
-	    list = xrealloc(list, (n + 2) * sizeof(char *));
+	    list = realloc(list, (n + 2) * sizeof(char *));
 	    if (!list) {
 		if (save) {
 		    save[n] = NULL;
 		    FreeStringList(save);
 		}
-		xfree(fullpath);
+		free(fullpath);
 		return NULL;
 	    }
-	    list[n] = xalloc(len + 1);
+	    list[n] = malloc(len + 1);
 	    if (!list[n]) {
 		FreeStringList(list);
-		xfree(fullpath);
+		free(fullpath);
 		return NULL;
 	    }
 	    strcpy(list[n], elem);
@@ -173,7 +173,7 @@ InitPathList(const char *path)
     }
     if (list)
 	list[n] = NULL;
-    xfree(fullpath);
+    free(fullpath);
     return list;
 }
 
@@ -244,7 +244,7 @@ InitPatterns(const char **patternlist)
 	for (i = 0, s = patternlist; *s; i++, s++)
 	    if (*s == DEFAULT_LIST)
 		i += sizeof(stdPatterns) / sizeof(stdPatterns[0]) - 1 - 1;
-	patterns = xalloc((i + 1) * sizeof(PatternRec));
+	patterns = malloc((i + 1) * sizeof(PatternRec));
 	if (!patterns) {
 	    return NULL;
 	}
@@ -274,7 +274,7 @@ static void
 FreePatterns(PatternPtr patterns)
 {
     if (patterns && patterns != stdPatterns)
-	xfree(patterns);
+	free(patterns);
 }
 
 static const char **
@@ -290,7 +290,7 @@ InitSubdirs(const char **subdirlist)
     Bool indefault;
 
     if (subdirlist == NULL) {
-	subdirlist = tmp_subdirlist = xalloc(2 * sizeof(char *));
+	subdirlist = tmp_subdirlist = malloc(2 * sizeof(char *));
 	if (subdirlist == NULL)
 	    return NULL;
 	subdirlist[0] = DEFAULT_LIST;
@@ -315,16 +315,14 @@ InitSubdirs(const char **subdirlist)
 		if (**s == '/' || **s == '\\' || strchr(*s, ':') ||
 		    strstr(*s, "..")) {
 		    xf86Msg(X_ERROR, "InitSubdirs: Bad subdir: \"%s\"\n", *s);
-		    if (tmp_subdirlist)
-			xfree(tmp_subdirlist);
+		    free(tmp_subdirlist);
 		    return NULL;
 		}
 	    }
 	}
-	subdirs = xalloc((i * 2 + 1) * sizeof(char *));
+	subdirs = malloc((i * 2 + 1) * sizeof(char *));
 	if (!subdirs) {
-	    if (tmp_subdirlist)
-		xfree(tmp_subdirlist);
+	    free(tmp_subdirlist);
 	    return NULL;
 	}
 	i = 0;
@@ -344,19 +342,18 @@ InitSubdirs(const char **subdirlist)
 	    } else
 		slash = "";
 	    len += oslen + 2;
-	    if (!(subdirs[i] = xalloc(len))) {
+	    if (!(subdirs[i] = malloc(len))) {
 		while (--i >= 0)
-		    xfree(subdirs[i]);
-		xfree(subdirs);
-		if (tmp_subdirlist)
-		    xfree(tmp_subdirlist);
+		    free(subdirs[i]);
+		free(subdirs);
+		free(tmp_subdirlist);
 		return NULL;
 	    }
 	    /* tack on the OS name */
 	    sprintf(subdirs[i], "%s%s%s/", *s, slash, osname);
 	    i++;
 	    /* path as given */
-	    subdirs[i] = xstrdup(*s);
+	    subdirs[i] = strdup(*s);
 	    i++;
 	    s++;
 	    if (indefault && !s) {
@@ -367,8 +364,7 @@ InitSubdirs(const char **subdirlist)
 	}
 	subdirs[i] = NULL;
     }
-    if (tmp_subdirlist)
-	xfree(tmp_subdirlist);
+    free(tmp_subdirlist);
     return (const char **)subdirs;
 }
 
@@ -379,8 +375,8 @@ FreeSubdirs(const char **subdirs)
 
     if (subdirs) {
 	for (s = subdirs; *s; s++)
-	    xfree(*s);
-	xfree(subdirs);
+	    free(*s);
+	free(subdirs);
     }
 }
 
@@ -465,7 +461,7 @@ FindModule(const char *module, const char *dirname, const char **subdirlist,
 
     FreeSubdirs(subdirs);
     if (dirpath != dirname)
-	xfree(dirpath);
+	free(dirpath);
 
     return name;
 }
@@ -527,7 +523,7 @@ LoaderListDirs(const char **subdirlist, const char **patternlist)
 			    match[1].rm_so != -1) {
 			    len = match[1].rm_eo - match[1].rm_so;
 			    save = listing;
-			    listing = xrealloc(listing,
+			    listing = realloc(listing,
 					       (n + 2) * sizeof(char *));
 			    if (!listing) {
 				if (save) {
@@ -539,7 +535,7 @@ LoaderListDirs(const char **subdirlist, const char **patternlist)
 				FreePatterns(patterns);
 				return NULL;
 			    }
-			    listing[n] = xalloc(len + 1);
+			    listing[n] = malloc(len + 1);
 			    if (!listing[n]) {
 				FreeStringList(listing);
 				FreePathList(pathlist);
@@ -743,7 +739,7 @@ static ModuleDescPtr
 AddSibling(ModuleDescPtr head, ModuleDescPtr new)
 {
     new->sib = head;
-    return (new);
+    return new;
 }
 
 pointer
@@ -780,7 +776,7 @@ LoadSubModule(pointer _parent, const char *module,
 static ModuleDescPtr
 NewModuleDesc(const char *name)
 {
-    ModuleDescPtr mdp = xalloc(sizeof(ModuleDesc));
+    ModuleDescPtr mdp = malloc(sizeof(ModuleDesc));
 
     if (mdp) {
 	mdp->child = NULL;
@@ -793,7 +789,7 @@ NewModuleDesc(const char *name)
 	mdp->TearDownData = NULL;
     }
 
-    return (mdp);
+    return mdp;
 }
 
 ModuleDescPtr
@@ -944,7 +940,7 @@ doLoadModule(const char *module, const char *path, const char **subdirlist,
      * now check if the special data object <modulename>ModuleData is
      * present.
      */
-    p = xalloc(strlen(name) + strlen("ModuleData") + 1);
+    p = malloc(strlen(name) + strlen("ModuleData") + 1);
     if (!p) {
 	if (errmaj)
 	    *errmaj = LDR_NOMEM;
@@ -1021,9 +1017,9 @@ doLoadModule(const char *module, const char *path, const char **subdirlist,
   LoadModule_exit:
     FreePathList(pathlist);
     FreePatterns(patterns);
-    xfree(found);
-    xfree(name);
-    xfree(p);
+    free(found);
+    free(name);
+    free(p);
 
     return ret;
 }
@@ -1099,8 +1095,8 @@ UnloadModuleOrDriver(ModuleDescPtr mod)
 	UnloadModuleOrDriver(mod->child);
     if (mod->sib)
 	UnloadModuleOrDriver(mod->sib);
-    xfree(mod->name);
-    xfree(mod);
+    free(mod->name);
+    free(mod);
 }
 
 void
@@ -1122,8 +1118,8 @@ UnloadSubModule(pointer _mod)
     if (mod->child)
 	UnloadModuleOrDriver(mod->child);
 
-    xfree(mod->name);
-    xfree(mod);
+    free(mod->name);
+    free(mod);
 }
 
 static void
@@ -1241,7 +1237,7 @@ LoaderGetCanonicalName(const char *modname, PatternPtr patterns)
     for (p = patterns; p->pattern; p++)
 	if (regexec(&p->rex, s, 2, match, 0) == 0 && match[1].rm_so != -1) {
 	    len = match[1].rm_eo - match[1].rm_so;
-	    str = xalloc(len + 1);
+	    str = malloc(len + 1);
 	    if (!str)
 		return NULL;
 	    strncpy(str, s + match[1].rm_so, len);
@@ -1250,7 +1246,7 @@ LoaderGetCanonicalName(const char *modname, PatternPtr patterns)
 	}
 
     /* If there is no match, return the whole name minus the leading path */
-    return xstrdup(s);
+    return strdup(s);
 }
 
 /*
